#!/usr/bin/env python3
"""{{ agent_display_name }} Agent — Entry point.

Structure:
  app.py    — AbiCore instance
  tools.py  — @agent.tool decorators
  steps.py  — @agent.step decorators
  tasks.py  — @agent.task decorators
  main.py   — this file (imports + run)
"""

from app import agent
from {{ agent_file_name }} import {{ agent_class_name }}

# Import modules to register decorators
import tools   # noqa: F401
import steps   # noqa: F401
import tasks   # noqa: F401

agent.run({{ agent_class_name }}())
